@@ -97,10 +97,11 @@ impl<Source> PreprocessedFile<Source>
                 .collect::<Vec<_>>();
 
         // if the last line is not terminated with an EOL, assume it
-        let total_bytes = contents.as_ref().len();
+        let mut total_bytes = contents.as_ref().len();
         let last_line_byte = line_endings.last().unwrap_or(&0);
         if *last_line_byte < total_bytes-1 {
             line_ranges.push(last_line_byte+1 .. total_bytes);
+            total_bytes += 1; // virtual addition of one byte
         }
 
         let directives =
